@@ -6,7 +6,7 @@ use base qw(Exporter);
 
 sub _eval { eval $_[0] }  # empty lexical scope
 
-our $VERSION = '0.092';
+our $VERSION = '0.094';
 our @EXPORT = qw(
     byval
     elem
@@ -35,7 +35,7 @@ sub elem {
         }
     } elsif (defined $k) {
         for my $x (@$xs) {
-            return 1 if defined $x && $k eq $x;
+            return 1 if defined $x && !ref $x && $k eq $x;
         }
     } else {
         for my $x (@$xs) {
@@ -149,7 +149,7 @@ Data::Munge - various utility functions
  # print do { my $tmp = $text; $tmp =~ s/foo/bar/; $tmp };
  
  foo(mapval { chomp } @lines);
- # foo(map { my $tmp = $_; chomp $tmp; $_ } @lines);
+ # foo(map { my $tmp = $_; chomp $tmp; $tmp } @lines);
  
  print replace('Apples are round, and apples are juicy.', qr/apples/i, 'oranges', 'g');
  # "oranges are round, and oranges are juicy."
@@ -362,7 +362,7 @@ Lukas Mai, C<< <l.mai at web.de> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2011, 2013-2014 Lukas Mai.
+Copyright 2009-2011, 2013-2015 Lukas Mai.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
